%% HydroWatch.m
% ABOUT: This file contains the first draft of the HydroWatch
% postprocessing framework. The functioning of the file is
% based upon a .txt log file that is output by the BlueTooth
% Explorer of the onSEMICONDUCTORS com to UART dongle. 
%
% AUTHOR: Rebecca Hoehne
% 
% DATE UPDATED: 3.24.19
clc
clear
close all

%% Parse Log file
%this creates an output txt file from the log file
system('python logfileparse.py');

%% Read the ouput file into vector
out = readtable('Output1.csv');

%cast into double from table
LED=out.LED_code;
values=out.Hex_Output;
[m,n]=size(out);

%initialize the LEDs
L1=0;
L2=0;
L3=0;
L4=0;

% note units are in volts
for i=1:m
    code=LED(i,1);
    switch code
        case 1
            L1=L1+1;
            LED1(L1)=convertAFE(values(i));
            
        case 2
            L2=L2+1;
            LED2(L2)=convertAFE(values(i));
            
        case 3
            L3=L3+1;
            LED3(L3)=convertAFE(values(i));
            
        case 4
            L4=L4+1;
            LED4(L4)=convertAFE(values(i));
    end
end


max=length(LED4);



time=linspace(0, 200*10^-3*length(LED4), length(LED4));


subplot(4,1,1);
plot(time, LED1(1:max));
title('LED1: 450nm')
xlabel('time (s)')
ylabel('voltage (v)')

subplot(4,1, 2);
plot(time, LED2(1:max));
title('LED2: 670nm')
xlabel('time (s)')
ylabel('voltage (v)')

subplot(4,1,3);
plot(time, LED3(1:max));
title('LED3: 1200nm')
xlabel('time (s)')
ylabel('voltage (v)')

subplot(4,1,4);
plot(time, LED4(1:max));
title('LED4: 970nm')
xlabel('time (s)')
ylabel('voltage (v)')



%% determine if good skin contact
badcontact=false;
count=0;
for i=1:length(LED1)
    if LED1(i)==0 || LED1(i)>.15
        count=count+1;
    end
end

if count>=length(LED4)/2
    badcontact=true;
end

%% Read the ouput file into vector
out = readtable('Output.csv');

%cast into double from table
LEDpost=out.LED_code;
values=out.Hex_Output;
[m,n]=size(out);

%initialize the LEDs
L1=0;
L2=0;
L3=0;
L4=0;

% note units are in volts
for i=1:m
    code=LEDpost(i,1);
    switch code
        case 1
            L1=L1+1;
            LED1post(L1)=convertAFE(values(i));
            
        case 2
            L2=L2+1;
            LED2post(L2)=convertAFE(values(i));
            
        case 3
            L3=L3+1;
            LED3post(L3)=convertAFE(values(i));
            
        case 4
            L4=L4+1;
            LED4post(L4)=convertAFE(values(i));
    end
end


max=length(LED4post);

start=100


time=linspace(0, 200*10^-3*length(LED4post), length(LED4post));

figure
sgtitle('Rebecca''s Measured Data')

subplot(4,1,1);
plot(time, LED1post(1:max), time, LED1(start:max+start-1));
title('LED1: 450nm')
xlabel('time (s)')
ylabel('voltage (v)')
ylim([0 1.2])
legend('After','Before', 'Location', 'best')


subplot(4,1, 2);
plot(time, LED2post(1:max),time, LED2(start:max+start-1));
title('LED2: 670nm')
xlabel('time (s)')
ylabel('voltage (v)')
ylim([0 1.2])
legend('After','Before', 'Location', 'best')

subplot(4,1,3);
plot(time, LED3post(1:max),time, LED3(start:max+start-1));
title('LED3: 1200nm')
xlabel('time (s)')
ylabel('voltage (v)')
ylim([.02 .1])
legend('After','Before', 'Location', 'best')
text(4,.085,'\downarrow (4.065s, 0.05567V)')
text(4,.03,'\uparrow (4.065s, 0.04599V)')

subplot(4,1,4);
plot(time, LED4post(1:max),time, LED4(start:max+start-1));
title('LED4: 970nm')
xlabel('time (s)')
ylabel('voltage (v)')
ylim([0 .5])
legend('After','Before', 'Location', 'best')
